<input type="password" name="{{ field.name }}" value="{{ cstruct }}"
{% if field.widget.size %}
    size="{{ field.widget.size }}"
{% endif %}
{% if field.widget.css_class %}
    class="{{ field.widget.css_class }} textInput"
{% else %}
    class="textInput"
{% endif %}
id="{{ field.oid }}"/>
