<div>
  <span>Year</span>
  <span id="{{ field.oid }}-year">{{ year }}</span>
  <span>Month</span>
  <span id="{{ field.oid }}-month">{{ month }}</span>
  <span>Day</span>
  <span id="{{ field.oid }}-day">{{ day }}</span>
</div>
