<ul class="deformSet">
    <input type="hidden" name="__start__" value="{{ field.name }}:rename"/>
    {% for value, title in field.widget.values %}
        <li class="deformSet-item">
          <input
            {% if value == cstruct %}
            checked="True"
            {% endif %}
            {% if field.widget.css_class %}
            class="{{ field.widget.css_class }}"
            {% endif %}
            type="radio"
            name="{{ field.oid }}"
            value="{{ value }}"
            id="{{ field.oid }}-{{ loop.index0 }}"/>
          <label for="{{ field.oid }}-{{ loop.index0 }}">{{ title }}</label>
        </li>
    {% endfor %}
    <input type="hidden" name="__end__"/>
</ul>

