<input type="hidden" name="__start__" value="{{ field.name }}:mapping"/>
<div class="ctrlHolder">
    <label for="{{ field.oid }}">Password</label>
    <input type="password" name="{{ field.name }}" value="{{ cstruct }}"
         {% if field.widget.size %}
         size="{{ field.widget.size }}"
         {% endif %}
        class="textInput"
         id="{{ field.oid }}"/>
</div>
<div class="ctrlHolder">
    <label for="{{ field.oid }}-confirm">Confirm Password</label>
    <input type="password" name="{{ field.name }}-confirm" value="{{ confirm }}"
         {% if field.widget.size %}
         size="{{ field.widget.size }}"
         {% endif %}
         {% if field.widget.css_class %}
            class="{{ field.widget.css_class }} textInput"
         {% else %}
            class="textInput"
         {% endif %}
        id="{{ field.oid }}-confirm"/>
  </li>
</div>
<input type="hidden" name="__end__" value="{{ field.name }}:mapping"/>
